/*
    Copyright (c) 2009 Volker Krause <vkrause@kde.org>

    This library is free software; you can redistribute it and/or modify it
    under the terms of the GNU Library General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    This library is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
    License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to the
    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
    02110-1301, USA.
*/

#ifndef GLOBAL_H
#define GLOBAL_H

#include <QUrl>
#include <QStringList>

namespace Global {
Q_REQUIRED_RESULT QStringList typeFilter();
void setTypeFilter(const QStringList &filter);
void setPoFileName(const QString &poFileName);
Q_REQUIRED_RESULT QString poFileName();
Q_REQUIRED_RESULT QString assistant();
void setAssistant(const QString &assistant);

Q_REQUIRED_RESULT QString assistantBasePath();
Q_REQUIRED_RESULT QStringList assistants();

Q_REQUIRED_RESULT QString unpackAssistant(const QUrl &remotePackageUrl);
}

#endif
